@@ -1,6 +1,7 @@
 """GraphQL client, high performance, easy to use, sync/async support"""
 
-__version__ = "0.2.0"
+__version__ = "0.3.0"
 
-from .client import GraphQLClient as GraphQLClient
+from .client import AsyncClient as AsyncClient
+from .client import Client as Client
 from .request import GraphQLRequest as GraphQLRequest
